@@ -12,7 +12,9 @@ class BaseTransportMixin(object):
         """ Return C{ConnectionInfo} object from current transport """
         return ConnectionInfo(self.request.remote_ip,
                               self.request.cookies,
-                              self.request.arguments)
+                              self.request.arguments,
+                              self.request.headers,
+                              self.request.path)
 
     def session_closed(self):
         """ Called by the session, when it gets closed """
